@@ -76,7 +76,7 @@ setMethodS3("bgAdjustOptical", "AffymetrixCelFile", function(this, path, minimum
   pathname <- AffymetrixFile$renameToUpperCaseExt(pathname);
 
   # Already corrected?
-  if (isFile(pathname) && skip) {
+  if (skip && isFile(pathname)) {
     verbose && cat(verbose, "Optical background adjusted data file already exists: ", pathname);
     # make sure CDF gets inherited from source object
     res <- fromFile(this, pathname);
@@ -106,20 +106,29 @@ setMethodS3("bgAdjustOptical", "AffymetrixCelFile", function(this, path, minimum
   verbose && printf(verbose, "Correction: -(%.2f-%.2f) = %+.2f\n",
                                          arrayMinimum, minimum, -xdiff);
   x[subsetToUpdate] <- x[subsetToUpdate] - xdiff;
-  rm(subsetToUpdate);
+  # Not needed anymore
+  subsetToUpdate <- NULL;
   verbose && exit(verbose);
 
   # Write adjusted data to file
   verbose && enter(verbose, "Writing adjusted probe signals");
 
+  # Write to a temporary file (allow rename of existing one if forced)
+  isFile <- (!skip && isFile(pathname));
+  pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
   # Create CEL file to store results, if missing
   verbose && enter(verbose, "Creating CEL file for results, if missing");
-  createFrom(this, filename=pathname, path=NULL, verbose=less(verbose));
+  createFrom(this, filename=pathnameT, path=NULL, verbose=less(verbose));
   verbose && exit(verbose);
 
   verbose && enter(verbose, "Writing adjusted intensities");
-  updateCel(pathname, intensities=x);
+  updateCel(pathnameT, intensities=x);
   verbose && exit(verbose);
+
+  # Rename temporary file
+  pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
   verbose && exit(verbose);
 
   # Return new BG adjusted data file object, making sure CDF is
@@ -246,7 +255,7 @@ setMethodS3("bgAdjustGcrma", "AffymetrixCelFile", function(this, path, type=c("f
   cdf <- getCdf(this);
 
   # Already corrected?
-  if (isFile(pathname) && skip) {
+  if (skip && isFile(pathname)) {
     verbose && cat(verbose, "GC-adjusted data file already exists: ", pathname);
     # inheritance of CDF
     res <- fromFile(this, pathname);
@@ -372,7 +381,8 @@ setMethodS3("bgAdjustGcrma", "AffymetrixCelFile", function(this, path, type=c("f
     pmCells <- pmCells[keep];
     apm <- apm[keep];
     verbose && exit(verbose);
-    rm(keep);
+    # Not needed anymore
+    keep <- NULL;
 
     verbose && enter(verbose, "Dropping negative controls with missing signals or missing affinities");
     n0 <- length(ncs);
@@ -391,7 +401,8 @@ setMethodS3("bgAdjustGcrma", "AffymetrixCelFile", function(this, path, type=c("f
     ncs <- ncs[keep];
     anc <- anc[keep];
     verbose && exit(verbose);
-    rm(keep);
+    # Not needed anymore
+    keep <- NULL;
 
     verbose && cat(verbose, "Number of PMs: ", length(pm));
     verbose && cat(verbose, "Number of negative controls: ", length(ncs));
@@ -408,7 +419,8 @@ setMethodS3("bgAdjustGcrma", "AffymetrixCelFile", function(this, path, type=c("f
   } # if (type == ...)
 
   # Not needed anymore
-  rm(anc, ncs, mm, amm);
+  # Not needed anymore
+  anc <- ncs <- mm <- amm <- NULL;
 
   verbose && exit(verbose);
 
@@ -430,7 +442,8 @@ setMethodS3("bgAdjustGcrma", "AffymetrixCelFile", function(this, path, type=c("f
   }
 
   # Not needed anymore
-  rm(apm);
+  # Not needed anymore
+  apm <- NULL;
 
 
   # don't understand this, but it was in original bg.adjust.gcrma(), so
@@ -450,15 +463,23 @@ setMethodS3("bgAdjustGcrma", "AffymetrixCelFile", function(this, path, type=c("f
   # Write adjusted data to file
   verbose && enter(verbose, "Writing adjusted probe signals");
 
+  # Write to a temporary file (allow rename of existing one if forced)
+  isFile <- (!skip && isFile(pathname));
+  pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
   # Create CEL file to store results, if missing
   verbose && enter(verbose, "Creating CEL file for results, if missing");
-  createFrom(this, filename=pathname, path=NULL, verbose=less(verbose));
+  createFrom(this, filename=pathnameT, path=NULL, verbose=less(verbose));
   verbose && exit(verbose);
 
   verbose && enter(verbose, "Writing adjusted intensities");
   verbose && cat(verbose, "Number of cells (PMs only): ", length(pmCells));
-  updateCel(pathname, indices=pmCells, intensities=pm);
+  updateCel(pathnameT, indices=pmCells, intensities=pm);
   verbose && exit(verbose);
+
+  # Rename temporary file
+  pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
   verbose && exit(verbose);
 
   # Return new background corrected data file object
@@ -544,7 +565,7 @@ setMethodS3("bgAdjustRma", "AffymetrixCelFile", function(this, path, pmonly=TRUE
   setCdf(this, cdf);
 
   # Already corrected?
-  if (isFile(pathname) && skip) {
+  if (skip && isFile(pathname)) {
     verbose && cat(verbose, "Background-adjusted data file already exists: ", pathname);
     # inheritance of CDF
     res <- fromFile(this, pathname);
@@ -592,19 +613,27 @@ setMethodS3("bgAdjustRma", "AffymetrixCelFile", function(this, path, pmonly=TRUE
   # Write adjusted data to file
   verbose && enter(verbose, "Writing adjusted probe signals");
 
+  # Write to a temporary file (allow rename of existing one if forced)
+  isFile <- (!skip && isFile(pathname));
+  pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
   # Create CEL file to store results, if missing
   verbose && enter(verbose, "Creating CEL file for results, if missing");
-  createFrom(this, filename=pathname, path=NULL, verbose=less(verbose));
+  createFrom(this, filename=pathnameT, path=NULL, verbose=less(verbose));
   verbose && exit(verbose);
 
   verbose && enter(verbose, "Writing adjusted intensities");
-  updateCel(pathname, indices=pmCells, intensities=pm);
+  updateCel(pathnameT, indices=pmCells, intensities=pm);
   verbose && exit(verbose);
 
+  # Rename temporary file
+  pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
   verbose && exit(verbose);
 
   # get rid of redundant objects to save space
-  rm(pm, pmCells);
+  # Not needed anymore
+  pm <- pmCells <- NULL;
 
   # Garbage collection
   gc <- gc();
