@@ -233,8 +233,7 @@ setMethodS3("as.character", "AffymetrixCelSet", function(x, ...) {
   }
   s <- c(s, sprintf("Total file size: %.2fMB", getFileSize(this)/1024^2));
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
-  class(s) <- "GenericSummary";
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
