@@ -107,7 +107,8 @@ setMethodS3("importFromDChip", "AffymetrixCelSet", function(static, path, name=N
     x <- rep(1:ncol, each=nrow);
     writeMap <- as.vector(y*ncol + x);
     readMap <- invertMap(writeMap);
-    rm(x, y, h, nrow, ncol, writeMap);
+    # Not needed anymore
+    x <- y <- h <- nrow <- ncol <- writeMap <- NULL;
   } else {
     readMap <- NULL;
   }
@@ -162,7 +163,8 @@ setMethodS3("importFromDChip", "AffymetrixCelSet", function(static, path, name=N
     verbose && exit(verbose);
   }
 
-  rm(readMap);
+  # Not needed anymore
+  readMap <- NULL;
 
   # Garbage collect
   gc <- gc();
