@@ -53,8 +53,7 @@ setMethodS3("as.character", "AromaChipTypeAnnotationFile", function(x, ...) {
 
   s <- c(s, sprintf("Chip type: %s", getChipType(this)));
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
-  class(s) <- "GenericSummary";
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
