@@ -172,8 +172,7 @@ setMethodS3("as.character", "CnagCfhSet", function(x, ...) {
   s <- c(s, sprintf("Time period: %s -- %s", ts[1], ts[2]));
   s <- c(s, sprintf("Total file size: %.2fMB", getFileSize(this)/1024^2));
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
-  class(s) <- "GenericSummary";
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
@@ -844,7 +843,7 @@ setMethodS3("getAverageFile", "CnagCfhSet", function(this, name=NULL, prefix="av
     paths <- c(path);
 
     # Drop tags from root path?
-    if (getOption(aromaSettings, "devel/dropRootPathTags", FALSE)) {
+    if (getOption(aromaSettings, "devel/dropRootPathTags", TRUE)) {
       path <- dropRootPathTags(path, depth=2, verbose=less(verbose, 5));
       paths <- c(paths, path);
       paths <- unique(paths);
