@@ -92,8 +92,7 @@ setMethodS3("as.character", "DChipDcpSet", function(x, ...) {
   s <- c(s, sprintf("Names: %s [%d]", hpaste(names), n));
   s <- c(s, sprintf("Total file size: %.2fMB", getFileSize(this)/1024^2));
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
-  class(s) <- "GenericSummary";
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
