@@ -157,7 +157,8 @@ setMethodS3("getDesignMatrix", "MatNormalization", function(this, cells=NULL, mo
   designMatrix <- cbind(nT, A, C, G, rowSums(A)^2, rowSums(C)^2, rowSums(G)^2, nT^2, log(as.integer(ms[,1])));
 
   # Garbage collect
-  rm(nT,G,A,C,ms,sm);
+  # Not needed anymore
+  nT <- G <- A <- C <- ms <- sm <- NULL;
   gc <- gc();
   verbose && print(verbose, gc);
 
@@ -349,7 +350,8 @@ setMethodS3("predictOne", "MatNormalization", function(this, fit, ram=NULL, ...,
     verbose && exit(verbose);
   } # while (...)
 
-  rm(X,indSubset);
+  # Not needed anymore
+  X <- indSubset <- NULL;
   gc <- gc();
 
   #nbrOfBins <- this$.nbrOfBins
@@ -507,12 +509,14 @@ setMethodS3("process", "MatNormalization", function(this, ..., ram=NULL, force=F
 
       xtyList[[ii]] <- xtyList[[ii]] + crossprod(X, y);
 
-      rm(y);
+      # Not needed anymore
+      y <- NULL;
       verbose && exit(verbose);
     } # for (ii ...)
     verbose && exit(verbose);
 
-    rm(X);
+    # Not needed anymore
+    X <- NULL;
 
     # Next chunk
     idxs <- idxs[-head];
@@ -528,7 +532,8 @@ setMethodS3("process", "MatNormalization", function(this, ..., ram=NULL, force=F
   verbose && exit(verbose);
 
   # Not needed anmore
-  rm(xtx, xtyList);
+  # Not needed anymore
+  xtx <- xtyList <- NULL;
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -622,19 +627,28 @@ setMethodS3("process", "MatNormalization", function(this, ..., ram=NULL, force=F
       filename <- sprintf("%s.CEL", fullname);
       pathname <- Arguments$getWritablePathname(filename, path=outputPath, ...);
 
+      # Write to a temporary file (allow rename of existing one if forced)
+      isFile <- isFile(pathname);
+      pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
       # Create CEL file to store results, if missing
       verbose && enter(verbose, "Creating CEL file for results, if missing");
-      createFrom(df, filename=pathname, path=NULL, verbose=less(verbose));
+      createFrom(df, filename=pathnameT, path=NULL, verbose=less(verbose));
       verbose && exit(verbose);
 
       verbose2 <- as.logical(verbose);
-      updateCel(pathname, indices=cellsChunk, intensities=2^mu, verbose=verbose2);
+      updateCel(pathnameT, indices=cellsChunk, intensities=2^mu, verbose=verbose2);
+
+      # Rename temporary file
+      pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
       verbose && exit(verbose);
     } # for (ii ...)
     verbose && exit(verbose);
 
     # Not needed anymore
-    rm(mu);
+    # Not needed anymore
+    mu <- NULL;
 
     # Garbage collect
     gc <- gc();
@@ -687,14 +701,24 @@ setMethodS3("process", "MatNormalization", function(this, ..., ram=NULL, force=F
 
     #return(list(y=y,mu=mu,r=r))
 
+    # Write to a temporary file (allow rename of existing one if forced)
+    isFile <- isFile(pathname);
+    pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
     # Create CEL file to store results, if missing
     verbose && enter(verbose, "Creating CEL file for results, if missing");
-    createFrom(df, filename=pathname, path=NULL, verbose=less(verbose));
+    createFrom(df, filename=pathnameT, path=NULL, verbose=less(verbose));
     verbose && exit(verbose);
 
     verbose2 <- as.logical(verbose);
-    updateCel(pathname, indices=cellsToFit, intensities=2^r, verbose=verbose2);
-    rm(q,ss,ssvar,v,r,y);
+    updateCel(pathnameT, indices=cellsToFit, intensities=2^r, verbose=verbose2);
+
+    # Not needed anymore
+    q <- ss <- ssvar <- v <- r <- y <- NULL;
+
+    # Rename temporary file
+    pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
     gc <- gc();
     verbose && print(verbose, gc);
 
