@@ -56,9 +56,7 @@ setMethodS3("as.character", "SpatialReporter", function(x, ...) {
   s <- c(s, paste("Color maps:", paste(colorMaps, collapse="; ")));
   s <- c(s, sprintf("Path: %s", getPath(this)));
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
-  class(s) <- "GenericSummary";
-
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
